#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

import django
from django.core import mail
from django.test import Client, override_settings, SimpleTestCase

from django_ignorebots import ALL_URLS

os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.settings'
django.setup()


@override_settings(
    IGNORABLE_404_URLS=ALL_URLS,
)
class TestIgnoreBotsURLS(SimpleTestCase):
    """Tests for `django_ignorebots` package."""

    def setUp(self):
        self.client = Client(
            HTTP_REFERER='http://example.com',
        )

    def test_unignored_url(self):
        """Test a 404 URL that shouldn't be ignored."""
        self.assertEqual(len(mail.outbox), 0)
        self.client.get('/dont-ignore-me')
        self.assertEqual(len(mail.outbox), 1)

    def test_ignored_urls(self):
        """Test known bot 404 URLs that should be ignored."""
        urls = [
            '/.bitcoin/wallet.dat',
            '/axis2/axis2-admin/login',
            '/backup/bitcoin/',
            '/backup/bitcoin/wallet.dat',
            '/backup/wallet.dat',
            '/bitcoin/',
            '/bitcoin/backup/wallet.dat',
            '/blog/wp-includes/wlwmanifest.xml',
            '/cms/wp-includes/wlwmanifest.xml',
            '/site/wp-admin/',
            '/site/wp-includes/wlwmanifest.xml',
            '/wordpress/wp-admin/',
            '/wordpress/wp-includes/wlwmanifest.xml',
            '/wp/wp-includes/wlwmanifest.xml',
            '/wp-admin/',
            '/wp-content/plugins/dzs-zoomsounds/admin/upload.php',
            '/wp-content/plugins/estatik/readme.txt',
            '/wp-content/plugins/wp-vertical-gallery/readme.txt',
            '/wp-content/plugins/wp-formgenerator/changelog.txt',
            '/wp-includes/wlwmanifest.xml',
            '/wp-login.php',
            '/xmlrpc.php',
        ]
        for url in urls:
            with self.subTest(msg='Testing known bot url', url=url):
                mail.outbox.clear()
                self.client.get(url)
                self.assertEqual(len(mail.outbox), 0)



# -*- coding: utf-8 -*-

"""Top-level package for django-ignorebots."""

__author__ = """Alister Cordiner"""
__email__ = 'acordiner@gmail.com'
__version__ = '0.1.0'


import re

ADMIN_URLS = [re.compile(url) for url in [
    r'^/axis2/axis2-admin/login$',
]]

BITCOIN_URLS = [re.compile(url) for url in [
    r'/wallet\.dat$',
    r'^(/backup)?/\.?bitcoin/.*$',
]]

WORDPRESS_URLS = [re.compile(url) for url in [
    r'^/xmlrpc\.php.*$',
    r'/wp-(content|includes|admin)/.*$',
    r'/wp-login\.php$',
]]

ALL_URLS = ADMIN_URLS + BITCOIN_URLS + WORDPRESS_URLS



ROOT_URLCONF='tests.urls'
SECRET_KEY='---foobar--'
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
    'NAME': ':memory:',
    }
}
MANAGERS=('foobar@example.com',)
ALLOWED_HOSTS = ['testserver']

DEBUG=False
EMAIL_BACKEND = 'django.core.mail.backends.locmem.EmailBackend'

MIDDLEWARE = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.common.BrokenLinkEmailsMiddleware',
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.admin',
)
